@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ollama-buddy" "1.0.0"
+(define-package "ollama-buddy" "20250723.759"
   "Ollama LLM AI Assistant ChatGPT Claude Gemini Grok Support."
   '((emacs "28.1"))
   :url "https://github.com/captainflasmr/ollama-buddy"
